@@ -22,7 +22,7 @@ impl Cw1Contract {
         Ok(WasmMsg::Execute {
             contract_addr: self.addr().into(),
             msg: to_binary(&msg)?,
-            send: vec![],
+            funds: vec![],
         }
         .into())
     }
